@@ -14,7 +14,7 @@ package Net::SSH2::Cisco;
 # - I tried to create a child class of Net::SSH2 to no avail due to
 #   the C-type inside-out object it returns and my lack of experience.
 #
-# - I tried to pass a Net::SSH2 connetion to Net::Telnet(::Cisco) fhopen()
+# - I tried to pass a Net::SSH2 connection to Net::Telnet(::Cisco) fhopen()
 #   method, but it returned:
 #
 #     Not a GLOB reference at [...]/perl/vendor/lib/Net/Telnet.pm line 679.
@@ -29,9 +29,10 @@ package Net::SSH2::Cisco;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our @ISA;
 
+use version;
 use Net::SSH2 0.51;
 use Socket qw(inet_ntoa AF_INET IPPROTO_TCP);
 my $HAVE_IO_Socket_IP = 0;
@@ -130,6 +131,8 @@ sub new {
                 $fh_open = $args{$_}
             } elsif (/^-?host$/i) {
                 $host = $args{$_}
+            } elsif (/^-?ignore_warnings$/i) {
+                $self->{ignore_warnings} = $args{$_}
             } elsif (/^-?input_log$/i) {
                  $self->input_log($args{$_})
                     or return;
@@ -155,9 +158,11 @@ sub new {
             } elsif (/^-?timeout$/i) {
                 $self->timeout($args{$_})
             } elsif (/^-?waitfor_clear$/i) {
-                $self->waitfor_clear($args{$_});
+                $self->waitfor_clear($args{$_})
             } elsif (/^-?waitfor_pause$/i) {
-                $self->waitfor_pause($args{$_});
+                $self->waitfor_pause($args{$_})
+            } elsif (/^-?warnings$/i) {
+                $self->{warnings} = $args{$_}
             } else {
                 # pass through
                 #$params{$_} = $args{$_}
@@ -916,7 +921,8 @@ sub open {
         }
         # connect if IPv4
         if ($family eq 'ipv4') {
-            $r = $ssh->connect($host, $port, Timeout => $timeout)
+            $ssh->timeout($timeout*1000); # timeout is in millisecs
+            $r = $ssh->connect($host, $port)
 
         # if IPv6, Net::SSH2 doesn't yet support,
         # so need to create our own IO::Socket::IP
@@ -1261,6 +1267,12 @@ sub waitfor_pause {
     return $self->{waitfor_pause}
 }
 
+sub warnings {
+    my ($self, $arg) = @_;
+    $self->{warnings} = $arg if defined $arg;
+    return $self->{warnings}
+}
+
 #### PRIVATE ####
 
 sub _append_lineno {
@@ -1647,7 +1659,7 @@ sub _resolv {
 
     # address check
     # new way
-    if ($Socket::VERSION >= 1.94) {
+    if (version->parse($Socket::VERSION) >= version->parse(1.94)) {
         my %hints = (
             family   => $AF_UNSPEC,
             protocol => IPPROTO_TCP,
@@ -1674,7 +1686,7 @@ sub _resolv {
 
     # resolve
     # new way
-    if ($Socket::VERSION >= 1.94) {
+    if (version->parse($Socket::VERSION) >= version->parse(1.94)) {
         my %hints = (
             family   => $family,
             protocol => IPPROTO_TCP
@@ -1814,7 +1826,7 @@ inside-out object it returns and my lack of experience.
 
 =item *
 
-Pass a Net::SSH2(::Channel) connetion to Net::Telnet(::Cisco) fhopen()
+Pass a Net::SSH2(::Channel) connection to Net::Telnet(::Cisco) fhopen()
 method, but it returned:
 
 C<Not a GLOB reference at [...]/perl/vendor/lib/Net/Telnet.pm line 679.>
@@ -1896,6 +1908,12 @@ their documentation first, and then come back here.
         [Timeout                 => $secs,]       # 10
         [Waitfor_clear           => $mode,]       # 0
         [Waitfor_pause           => $millisecs,]  # 0.2
+        [Warnings]               => $matchop,]    # /(?mx:^% Unknown VPN
+                                                        |^%IP routing table VRF.* does not exist. Create first$
+                                                        |^%No CEF interface information
+                                                        |^%No matching route to delete$
+                                                        |^%Not all config may be removed and may reappear after reactivating
+                                                    )/
     );
 
 This is the constructor for Net::SSH2::Cisco objects.  A new object is
@@ -1906,7 +1924,7 @@ If the I<$host> argument is given then the object is opened by
 connecting to TCP I<$port> on I<$host>.  Also see C<connect()>.  The new
 object returned is given the defaults listed above.
 
-=item B<always_waitfor_prompt> - waitfor and cmd prompt behaviour
+=item B<always_waitfor_prompt> - waitfor and cmd prompt behavior
 
     $mode = $obj->always_waitfor_prompt;
 
@@ -1928,7 +1946,7 @@ prompt.
 
 IOS pages output by default. It expects human eyes to be reading the
 output, not programs.  Humans hit the spacebar to scroll page by
-page so autopage() mimicks that behaviour.  This is the slow way to
+page so autopage() mimics that behavior.  This is the slow way to
 handle paging.  Consider sending "terminal length 0" as the first C<cmd()>.
 
 =item B<binmode> - toggle newline translation
@@ -2064,7 +2082,7 @@ or not it is matched in the first line of command output.
 This method opens a TCP connection to I<$port> on I<$host> for the IP
 address I<$family>.  If C<$filehandle> is provided, other options are
 ignored.  If any of the arguments are missing then the current attribute
-value for the object is used.  Specifing any optional named parameters
+value for the object is used.  Specifying any optional named parameters
 overrides the current setting for this call to C<connect()>.
 
 This essentially performs a Net::SSH2 C<connect()> call.
@@ -2219,12 +2237,12 @@ requires IO::Socket::IP be installed.
 This method associates the open filehandle I<$fh> with I<$obj> for
 further I/O.  Filehandle I<$fh> must already be opened.
 
-To support IPv6 in Net::SSH2, you need to open an IO::Socket::IP object
-and pass that to C<connect()>.  In this modules, Net::SSH2::Cisco takes
-care of IPv6 for you with the C<family()> method by essentially doing
-the same thing in the background.  If for some reason you're dropping
-this into existing code, you may already create your own IO object, so
-this allows for those existing instances.
+To support IPv6 in older versions of Net::SSH2, you may need to open an 
+IO::Socket::IP object and pass that to C<connect()>.  In this module, 
+Net::SSH2::Cisco takes care of IPv6 for you with the C<family()> method 
+by essentially doing the same thing in the background.  If for some reason 
+you're dropping this into existing code, you may already create your own 
+IO object, so this allows for those existing instances.
 
 =item B<host> - name or IP address of remote host
 
@@ -2338,7 +2356,7 @@ This method returns the last prompt read by C<cmd()>.  See C<prompt()>.
     );
 
 This method performs a login with Net::SSH2 authentication methods.
-Currenly, only C<auth_password> is supported.
+Currently, only C<auth_password> is supported.
 
 Upon successful connection, a Net::SSH2::Channel object is created and:
 
@@ -2730,6 +2748,15 @@ C<cmd()> and C<enable>.  This adds a slight delay after sending the
 command and before reading the result to compensate.  You should not 
 have to change the default.
 
+=item B<warnings> - matchop used by ignore_warnings()
+
+    $boolean = $obj->warnings;
+
+    $boolean = $obj->warnings($matchop);
+
+Not all strings that begin with a '%' are really errors. Some are just 
+warnings. Cisco calls these the CIPMIOSWarningExpressions.
+
 =back
 
 =head1 EXAMPLES
